Documentation
¶
Overview ¶
Package vtgateservice is a generated protocol buffer package.
It is generated from these files:
vtgateservice.proto
It has these top-level messages:
Index ¶
- func RegisterVitessServer(s *grpc.Server, srv VitessServer)
- type VitessClient
- type VitessServer
- type Vitess_StreamExecuteClient
- type Vitess_StreamExecuteKeyRangesClient
- type Vitess_StreamExecuteKeyRangesServer
- type Vitess_StreamExecuteKeyspaceIdsClient
- type Vitess_StreamExecuteKeyspaceIdsServer
- type Vitess_StreamExecuteServer
- type Vitess_StreamExecuteShardsClient
- type Vitess_StreamExecuteShardsServer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterVitessServer ¶
func RegisterVitessServer(s *grpc.Server, srv VitessServer)
Types ¶
type VitessClient ¶
type VitessClient interface {
// Execute tries to route the query to the right shard.
// It depends on the query and bind variables to provide enough
// information in conjonction with the vindexes to route the query.
// API group: v3 API (alpha)
Execute(ctx context.Context, in *vtgate.ExecuteRequest, opts ...grpc.CallOption) (*vtgate.ExecuteResponse, error)
// ExecuteShards executes the query on the specified shards.
// API group: Custom Sharding
ExecuteShards(ctx context.Context, in *vtgate.ExecuteShardsRequest, opts ...grpc.CallOption) (*vtgate.ExecuteShardsResponse, error)
// ExecuteKeyspaceIds executes the query based on the specified keyspace ids.
// API group: Range-based Sharding
ExecuteKeyspaceIds(ctx context.Context, in *vtgate.ExecuteKeyspaceIdsRequest, opts ...grpc.CallOption) (*vtgate.ExecuteKeyspaceIdsResponse, error)
// ExecuteKeyRanges executes the query based on the specified key ranges.
// API group: Range-based Sharding
ExecuteKeyRanges(ctx context.Context, in *vtgate.ExecuteKeyRangesRequest, opts ...grpc.CallOption) (*vtgate.ExecuteKeyRangesResponse, error)
// ExecuteEntityIds executes the query based on the specified external id to keyspace id map.
// API group: Range-based Sharding
ExecuteEntityIds(ctx context.Context, in *vtgate.ExecuteEntityIdsRequest, opts ...grpc.CallOption) (*vtgate.ExecuteEntityIdsResponse, error)
// ExecuteBatchShards executes the list of queries on the specified shards.
// API group: Custom Sharding
ExecuteBatchShards(ctx context.Context, in *vtgate.ExecuteBatchShardsRequest, opts ...grpc.CallOption) (*vtgate.ExecuteBatchShardsResponse, error)
// ExecuteBatchKeyspaceIds executes the list of queries based on the specified keyspace ids.
// API group: Range-based Sharding
ExecuteBatchKeyspaceIds(ctx context.Context, in *vtgate.ExecuteBatchKeyspaceIdsRequest, opts ...grpc.CallOption) (*vtgate.ExecuteBatchKeyspaceIdsResponse, error)
// StreamExecute executes a streaming query based on shards.
// It depends on the query and bind variables to provide enough
// information in conjonction with the vindexes to route the query.
// Use this method if the query returns a large number of rows.
// API group: v3 API (alpha)
StreamExecute(ctx context.Context, in *vtgate.StreamExecuteRequest, opts ...grpc.CallOption) (Vitess_StreamExecuteClient, error)
// StreamExecuteShards executes a streaming query based on shards.
// Use this method if the query returns a large number of rows.
// API group: Custom Sharding
StreamExecuteShards(ctx context.Context, in *vtgate.StreamExecuteShardsRequest, opts ...grpc.CallOption) (Vitess_StreamExecuteShardsClient, error)
// StreamExecuteKeyspaceIds executes a streaming query based on keyspace ids.
// Use this method if the query returns a large number of rows.
// API group: Range-based Sharding
StreamExecuteKeyspaceIds(ctx context.Context, in *vtgate.StreamExecuteKeyspaceIdsRequest, opts ...grpc.CallOption) (Vitess_StreamExecuteKeyspaceIdsClient, error)
// StreamExecuteKeyRanges executes a streaming query based on key ranges.
// Use this method if the query returns a large number of rows.
// API group: Range-based Sharding
StreamExecuteKeyRanges(ctx context.Context, in *vtgate.StreamExecuteKeyRangesRequest, opts ...grpc.CallOption) (Vitess_StreamExecuteKeyRangesClient, error)
// Begin a transaction.
// API group: Transactions
Begin(ctx context.Context, in *vtgate.BeginRequest, opts ...grpc.CallOption) (*vtgate.BeginResponse, error)
// Commit a transaction.
// API group: Transactions
Commit(ctx context.Context, in *vtgate.CommitRequest, opts ...grpc.CallOption) (*vtgate.CommitResponse, error)
// Rollback a transaction.
// API group: Transactions
Rollback(ctx context.Context, in *vtgate.RollbackRequest, opts ...grpc.CallOption) (*vtgate.RollbackResponse, error)
// Split a query into non-overlapping sub queries
// API group: Map Reduce
SplitQuery(ctx context.Context, in *vtgate.SplitQueryRequest, opts ...grpc.CallOption) (*vtgate.SplitQueryResponse, error)
// GetSrvKeyspace returns a SrvKeyspace object (as seen by this vtgate).
// This method is provided as a convenient way for clients to take a
// look at the sharding configuration for a Keyspace. Looking at the
// sharding information should not be used for routing queries (as the
// information may change, use the Execute calls for that).
// It is convenient for monitoring applications for instance, or if
// using custom sharding.
// API group: Topology
GetSrvKeyspace(ctx context.Context, in *vtgate.GetSrvKeyspaceRequest, opts ...grpc.CallOption) (*vtgate.GetSrvKeyspaceResponse, error)
}
func NewVitessClient ¶
func NewVitessClient(cc *grpc.ClientConn) VitessClient
type VitessServer ¶
type VitessServer interface {
// Execute tries to route the query to the right shard.
// It depends on the query and bind variables to provide enough
// information in conjonction with the vindexes to route the query.
// API group: v3 API (alpha)
Execute(context.Context, *vtgate.ExecuteRequest) (*vtgate.ExecuteResponse, error)
// ExecuteShards executes the query on the specified shards.
// API group: Custom Sharding
ExecuteShards(context.Context, *vtgate.ExecuteShardsRequest) (*vtgate.ExecuteShardsResponse, error)
// ExecuteKeyspaceIds executes the query based on the specified keyspace ids.
// API group: Range-based Sharding
ExecuteKeyspaceIds(context.Context, *vtgate.ExecuteKeyspaceIdsRequest) (*vtgate.ExecuteKeyspaceIdsResponse, error)
// ExecuteKeyRanges executes the query based on the specified key ranges.
// API group: Range-based Sharding
ExecuteKeyRanges(context.Context, *vtgate.ExecuteKeyRangesRequest) (*vtgate.ExecuteKeyRangesResponse, error)
// ExecuteEntityIds executes the query based on the specified external id to keyspace id map.
// API group: Range-based Sharding
ExecuteEntityIds(context.Context, *vtgate.ExecuteEntityIdsRequest) (*vtgate.ExecuteEntityIdsResponse, error)
// ExecuteBatchShards executes the list of queries on the specified shards.
// API group: Custom Sharding
ExecuteBatchShards(context.Context, *vtgate.ExecuteBatchShardsRequest) (*vtgate.ExecuteBatchShardsResponse, error)
// ExecuteBatchKeyspaceIds executes the list of queries based on the specified keyspace ids.
// API group: Range-based Sharding
ExecuteBatchKeyspaceIds(context.Context, *vtgate.ExecuteBatchKeyspaceIdsRequest) (*vtgate.ExecuteBatchKeyspaceIdsResponse, error)
// StreamExecute executes a streaming query based on shards.
// It depends on the query and bind variables to provide enough
// information in conjonction with the vindexes to route the query.
// Use this method if the query returns a large number of rows.
// API group: v3 API (alpha)
StreamExecute(*vtgate.StreamExecuteRequest, Vitess_StreamExecuteServer) error
// StreamExecuteShards executes a streaming query based on shards.
// Use this method if the query returns a large number of rows.
// API group: Custom Sharding
StreamExecuteShards(*vtgate.StreamExecuteShardsRequest, Vitess_StreamExecuteShardsServer) error
// StreamExecuteKeyspaceIds executes a streaming query based on keyspace ids.
// Use this method if the query returns a large number of rows.
// API group: Range-based Sharding
StreamExecuteKeyspaceIds(*vtgate.StreamExecuteKeyspaceIdsRequest, Vitess_StreamExecuteKeyspaceIdsServer) error
// StreamExecuteKeyRanges executes a streaming query based on key ranges.
// Use this method if the query returns a large number of rows.
// API group: Range-based Sharding
StreamExecuteKeyRanges(*vtgate.StreamExecuteKeyRangesRequest, Vitess_StreamExecuteKeyRangesServer) error
// Begin a transaction.
// API group: Transactions
Begin(context.Context, *vtgate.BeginRequest) (*vtgate.BeginResponse, error)
// Commit a transaction.
// API group: Transactions
Commit(context.Context, *vtgate.CommitRequest) (*vtgate.CommitResponse, error)
// Rollback a transaction.
// API group: Transactions
Rollback(context.Context, *vtgate.RollbackRequest) (*vtgate.RollbackResponse, error)
// Split a query into non-overlapping sub queries
// API group: Map Reduce
SplitQuery(context.Context, *vtgate.SplitQueryRequest) (*vtgate.SplitQueryResponse, error)
// GetSrvKeyspace returns a SrvKeyspace object (as seen by this vtgate).
// This method is provided as a convenient way for clients to take a
// look at the sharding configuration for a Keyspace. Looking at the
// sharding information should not be used for routing queries (as the
// information may change, use the Execute calls for that).
// It is convenient for monitoring applications for instance, or if
// using custom sharding.
// API group: Topology
GetSrvKeyspace(context.Context, *vtgate.GetSrvKeyspaceRequest) (*vtgate.GetSrvKeyspaceResponse, error)
}
type Vitess_StreamExecuteClient ¶
type Vitess_StreamExecuteClient interface {
Recv() (*vtgate.StreamExecuteResponse, error)
grpc.ClientStream
}
type Vitess_StreamExecuteKeyRangesClient ¶
type Vitess_StreamExecuteKeyRangesClient interface {
Recv() (*vtgate.StreamExecuteKeyRangesResponse, error)
grpc.ClientStream
}
type Vitess_StreamExecuteKeyRangesServer ¶
type Vitess_StreamExecuteKeyRangesServer interface {
Send(*vtgate.StreamExecuteKeyRangesResponse) error
grpc.ServerStream
}
type Vitess_StreamExecuteKeyspaceIdsClient ¶
type Vitess_StreamExecuteKeyspaceIdsClient interface {
Recv() (*vtgate.StreamExecuteKeyspaceIdsResponse, error)
grpc.ClientStream
}
type Vitess_StreamExecuteKeyspaceIdsServer ¶
type Vitess_StreamExecuteKeyspaceIdsServer interface {
Send(*vtgate.StreamExecuteKeyspaceIdsResponse) error
grpc.ServerStream
}
type Vitess_StreamExecuteServer ¶
type Vitess_StreamExecuteServer interface {
Send(*vtgate.StreamExecuteResponse) error
grpc.ServerStream
}
type Vitess_StreamExecuteShardsClient ¶
type Vitess_StreamExecuteShardsClient interface {
Recv() (*vtgate.StreamExecuteShardsResponse, error)
grpc.ClientStream
}
type Vitess_StreamExecuteShardsServer ¶
type Vitess_StreamExecuteShardsServer interface {
Send(*vtgate.StreamExecuteShardsResponse) error
grpc.ServerStream
}
Click to show internal directories.
Click to hide internal directories.