Documentation
¶
Overview ¶
Package throttlerclient defines the generic RPC client interface for the throttler service. It has to be implemented for the different RPC frameworks e.g. gRPC.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterFactory ¶
RegisterFactory allows a client implementation to register itself.
Types ¶
type Client ¶
type Client interface {
// MaxRates returns the current max rate for each throttler of the process.
MaxRates(ctx context.Context) (map[string]int64, error)
// SetMaxRate allows to change the current max rate for all throttlers
// of the process.
SetMaxRate(ctx context.Context, rate int64) ([]string, error)
// Close will terminate the connection and free resources.
Close()
}
Client defines the generic RPC interface for the throttler service.
Click to show internal directories.
Click to hide internal directories.